@@ -1,4 +1,4 @@
-freshr <- function() {
+freshr <- function(pkgexc = NULL, varexc = NULL) {
     #' Unload none-base packages and remove all objects from environment
     #'
     #' @description Ever experienced a time when you pass an R script to your
@@ -8,6 +8,9 @@ freshr <- function() {
     #'   create a fresh environment for you to test reproducibility before you
     #'   send your script to someone else.
     #'
+    #' @param pkgexc list of packages to exclude from removal
+    #' @param varexc list of variables to exclude from removal
+    #'
     #' @return This function returns no value. It is called for its side effect
     #'   of cleaning up the global environment at script's start up/
     #'
@@ -17,14 +20,14 @@ freshr <- function() {
 
     # Drop all variables from global workspace
     rm(
-        list = ls(all.names = TRUE, envir = parent.frame()),
+        list = setdiff(ls(all.names = TRUE, envir = parent.frame()), varexc),
         envir = parent.frame()
     )
 
     # Unload none-base packages from global environment
     # https://stackoverflow.com/questions/7505547/
-    pkgs <- names(sessionInfo()$otherPkgs)
-    if (!is.null(pkgs)) {
+    pkgs <- setdiff(names(sessionInfo()$otherPkgs), pkgexc)
+    if (!is.null(pkgs) && length(pkgs) > 0) {
         suppressWarnings(invisible(lapply(
             X              = paste0("package:", pkgs),
             FUN            = detach,
