@@ -3,7 +3,7 @@ testthat::test_that("Dropping Variables Work", {
     var1 <- "a"
     var2 <- 2
     var3 <- rep(var1, 10)
-    freshr::freshr()
+    freshr::freshr(pkgexc = "testthat")
     testthat::expect_equal(length(ls(envir = .GlobalEnv)), 0)
 
 })
@@ -11,8 +11,8 @@ testthat::test_that("Dropping Variables Work", {
 
 testthat::test_that("Dropping Packages Work", {
 
-    library(testthat)
-    freshr::freshr()
-    testthat::expect_equal(sessionInfo()$otherPkgs, NULL)
+    library(usethis)
+    freshr::freshr(pkgexc = "testthat")
+    testthat::expect_equal(names(sessionInfo()$otherPkgs), "testthat")
 
 })
